vault.auth.aws


APIcljprotocol

Vault AWS auth method

Vault AWS auth method

loginclj

(login client)
(login client {:keys [role aws-region aws-credentials]})

Logs in to Vault using AWS credentials as per https://developer.hashicorp.com/vault/api-docs/auth/aws#login. This uses the iam method.

By default, uses the AWS SDK's DefaultCredentialsProvider to get AWS credentials, and DefaultAwsRegionProviderChain to infer the region of the STS service.

Options:

  • :role: name of the role configured in Vault. If not provided, Vault infers the role name from the AWS credentials.

  • :aws-region: AWS region name (string) of the STS service

  • :aws-credentials: an AwsCredentials instance

Logs in to Vault using AWS credentials
as per <https://developer.hashicorp.com/vault/api-docs/auth/aws#login>.
This uses the `iam` method.

By default, uses the AWS SDK's `DefaultCredentialsProvider` to get AWS
credentials, and `DefaultAwsRegionProviderChain` to infer the region of the
STS service.

Options:

- `:role`: name of the role configured in Vault. If not provided, Vault
   infers the role name from the AWS credentials.

- `:aws-region`: AWS region name (string) of the STS service

- `:aws-credentials`: an `AwsCredentials` instance

with-mountclj

(with-mount client mount)

Configures the mount point of the AWS auth method, if it is not the default "aws".

Returns a new client. If mount is nil, returns a client with the default mount point.

Configures the mount point of the AWS auth method, if it is not the default "aws".

Returns a new client. If `mount` is nil, returns a client with the default
mount point.
sourceraw docstring

default-mountclj

Default mount point for the AWS auth method.

Default mount point for the AWS auth method.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries